AFRL labeling Collection Info (sarpy.annotation.afrl_elements.DetailCollectionInfo)
===================================================================================

.. automodule:: sarpy.annotation.afrl_elements.DetailCollectionInfo
    :members:
    :show-inheritance:
    :inherited-members:
